@@ -9,6 +9,12 @@
  ******************************************************************/
 
 #include "reportinterface.h"
+#include "config-drkonqi.h"
+
+#if HAVE_UNAME
+#include <cerrno>
+#include <sys/utsname.h>
+#endif
 
 #include <chrono>
 
@@ -16,10 +22,10 @@
 
 #include <KIO/TransferJob>
 #include <KLocalizedString>
+#include <KOSRelease>
 
 #include "backtracegenerator.h"
 #include "bugzillalib.h"
-#include "config-drkonqi.h"
 #include "crashedapplication.h"
 #include "debuggermanager.h"
 #include "drkonqi.h"
@@ -38,6 +44,42 @@ using namespace Qt::StringLiterals;
 // fashion as well.
 static const int s_maxReportSize = 65535;
 
+namespace
+{
+struct UnameValues {
+    QString kernelVersion;
+    QString rawDescription;
+};
+
+char *safe_strerror(int error)
+{
+    constexpr auto maxBufferSize = 1024;
+    thread_local std::array<char, maxBufferSize> buffer;
+    // The return value changes depending on CFLAGS, so we intentionally do not do anything with it!
+    strerror_r(error, buffer.data(), buffer.size());
+    return buffer.data();
+}
+
+UnameValues unameValues()
+{
+    struct utsname name{};
+    if (uname(&name) == -1) {
+        const auto error = u"uname failed: %1"_s.arg(QString::fromUtf8(safe_strerror(errno)));
+        qCWarning(DRKONQI_LOG) << qUtf8Printable(error);
+        return {.kernelVersion = error, .rawDescription = error};
+    }
+
+    return UnameValues{
+        .kernelVersion = QString::fromUtf8(name.release),
+        .rawDescription = u"%1 %2 %3 %4 %5"_s.arg(QString::fromUtf8(name.sysname), //
+                                                  QString::fromUtf8(name.nodename),
+                                                  QString::fromUtf8(name.release),
+                                                  QString::fromUtf8(name.version),
+                                                  QString::fromUtf8(name.machine)),
+    };
+}
+} // namespace
+
 ReportInterface::ReportInterface(QObject *parent)
     : QObject(parent)
     , m_sentryPostbox(DrKonqi::crashedApplication()->fakeExecutableBaseName(), std::make_shared<SentryNetworkConnection>())
@@ -324,6 +366,7 @@ QByteArray journalPriorityToSentryLevel(const QByteArray &priorityBytes)
 void ReportInterface::prepareEventPayload()
 {
     auto eventPayload = DrKonqi::debuggerManager()->backtraceGenerator()->sentryPayload();
+    const auto receivedEmptyPayload = eventPayload.isEmpty();
     auto document = QJsonDocument::fromJson(eventPayload);
     auto hash = document.object().toVariantMap();
 
@@ -333,6 +376,24 @@ void ReportInterface::prepareEventPayload()
     bool hadSomeVerbosity = false;
     bool hadIncompatibleQt = false;
 
+    constexpr auto TAGS_KEY = "tags"_L1;
+
+    {
+        auto tags = hash.take(TAGS_KEY).toHash();
+        for (const auto &[key, value] : DrKonqi::crashedApplication()->m_tags.asKeyValueRange()) {
+            tags.insert(key, value);
+        }
+        hash.insert(TAGS_KEY, tags);
+    }
+
+    {
+        QVariantHash extra;
+        for (const auto &[key, value] : DrKonqi::crashedApplication()->m_extraData.asKeyValueRange()) {
+            extra.insert(key, value);
+        }
+        hash.insert(u"extra"_s, extra);
+    }
+
     {
         QList<QVariant> breadcrumbs;
         const auto logs = DrKonqi::crashedApplication()->m_logs;
@@ -381,7 +442,22 @@ void ReportInterface::prepareEventPayload()
     }
 
     {
-        constexpr auto TAGS_KEY = "tags"_L1;
+        constexpr auto CONTEXTS_KEY = "contexts"_L1;
+        auto context = hash.take(CONTEXTS_KEY).toHash();
+        const auto uname = unameValues();
+        const KOSRelease os;
+        context.insert(u"os"_s,
+                       QVariantHash{
+                           {u"name"_s, os.name()}, //
+                           {u"version"_s, os.versionId()},
+                           {u"build"_s, os.buildId().isEmpty() ? os.variantId() : os.buildId()},
+                           {u"kernel_version"_s, uname.kernelVersion},
+                           {u"raw_description"_s, uname.rawDescription},
+                       });
+        hash.insert(CONTEXTS_KEY, context);
+    }
+
+    {
         auto tags = hash.take(TAGS_KEY).toHash();
         tags.insert(u"some_verbosity"_s, hadSomeVerbosity);
 
@@ -445,6 +521,11 @@ void ReportInterface::prepareEventPayload()
         hash.insert(u"level"_s, u"info"_s);
     }
 
+    if (receivedEmptyPayload) {
+        hash.insert(u"message"_s, "Empty Sentry payload from GDB"_ba);
+        hash.insert(u"level"_s, u"warning"_s);
+    }
+
     m_sentryPostbox.addEventPayload(QJsonDocument::fromVariant(hash));
     maybePickUpPostbox();
 }
